"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.OrchestratorStorage = void 0;
const lru_cache_1 = require("lru-cache");
class OrchestratorStorage {
    storage;
    constructor(options = { compilerCacheSize: 100 }) {
        this.storage = new lru_cache_1.LRUCache({
            max: options.compilerCacheSize,
            ttl: options.maxCompilerCacheKeepAlive,
            updateAgeOnGet: options.updateCompilerCacheKeepAlive
        });
    }
    has(orchestratorId) {
        return this.storage.has(orchestratorId);
    }
    get(orchestratorId) {
        return this.storage.get(orchestratorId);
    }
    set(orchestratorId, orchestratorApi) {
        return this.storage.set(orchestratorId, orchestratorApi);
    }
    clear() {
        this.storage.clear();
    }
    async testConnections() {
        return Promise.all([...this.storage.values()].map(api => api.testConnection()));
    }
    async testOrchestratorConnections() {
        return Promise.all([...this.storage.values()].map(api => api.testOrchestratorConnections()));
    }
    async releaseConnections() {
        await Promise.all([...this.storage.values()].map(api => api.release()));
        this.storage.clear();
    }
}
exports.OrchestratorStorage = OrchestratorStorage;
//# sourceMappingURL=OrchestratorStorage.js.map